<?php

//
// This file will be executed only once
if (defined("_ECRIRE_INC_OBJET")) return;
define("_ECRIRE_INC_OBJET", "1");

include_ecrire('inc_objet_base.php3');


//
// --- Creation of concrete class ----
//
// Two classes should be created :
//   - one for the factory
//   - one for the object describer
//
// The object describer must declare the constructor, which can
// be left empty.
//
// The factory must declare 1) the constructor, which normally adjusts
// fields name, of the sql table, and the object describer ;
// as well as 2) the new_object method, which takes the $id of an object as
// argument and initialises the fields of the new object according to the
// semantics chosen by the latter.
//
// Then, the factory should be instanciated and recorded and
// a global function to call objects should be provided. The simplest way is to
// copy the provided function and change the names.
//

// --------------------------------------------------------------------

//
// Articles factory
//

class ArticleFactory extends _ObjectFactory {
	// Initialising class variables
	function ArticleFactory() {
		$this->fast_vars_list = array('id_article', 'id_rubrique', 'id_secteur', 'titre', 'surtitre',
			'soustitre', 'descriptif', 'date', 'date_redac', 'visites', 'referers', 'statut');
		$this->slow_vars_list = array('chapo', 'texte', 'ps');
		$this->sql_table = 'spip_articles';
		$this->object_class = 'Article';
	}

	// Initialising object variables
	function new_object($id) {
		$this->set_object_field($id, 'titre', 'Nouvel article');
		$this->set_object_field($id, 'statut', 'poubelle');
	}
}

class Article extends _Object {
	// Do nothing
	function Article() {
	}
}

add_factory('article'); // Returns 'article_factory'

function fetch_article($critere, $fast = true) {
	return $GLOBALS['article_factory']->fetch_object($critere, $fast);
}


// --------------------------------------------------------------------

//
// Briefs factory
//

class BreveFactory extends _ObjectFactory {
	// Initialising class variables
	function BreveFactory() {
		$this->fast_vars_list = array('id_breve', 'id_rubrique', 'titre', 
			'lien_titre', 'lien_url', 'date_heure', 'statut');
		$this->slow_vars_list = array('texte');
		$this->sql_table = 'spip_breves';
		$this->object_class = 'Breve';
	}

	// Initialising object variables
	function new_object($id) {
		$this->set_object_field($id, 'titre', 'Nouvelle breve');
		$this->set_object_field($id, 'statut', 'refuse');
	}
}

class Breve extends _Object {
	// Do nothing
	function Breve() {
	}
}

add_factory('breve'); // Returns 'article_factory'

function fetch_breve($critere, $fast = true) {
	return $GLOBALS['breve_factory']->fetch_object($critere, $fast);
}


// --------------------------------------------------------------------

//
// Documents factory
//

class DocumentFactory extends _ObjectFactory {
	// Initialising class variables
	function DocumentFactory() {
		$this->fast_vars_list = array('id_document', 'id_vignette', 'id_type', 
			'titre', 'descriptif', 'fichier', 'largeur', 'hauteur', 'taille', 'mode', 'date');
		$this->slow_vars_list = '';
		$this->sql_table = 'spip_documents';
		$this->object_class = 'Document';
	}

	// Initialising object variables
	function new_object($id) {
		$this->set_object_field($id, 'titre', 'nouveau document');
	}
}

class Document extends _Object {
	// Do nothing
	function Document() {
	}
}

add_factory('document'); // Returns 'article_factory'

function fetch_document($critere, $fast = true) {
	return $GLOBALS['document_factory']->fetch_object($critere, $fast);
}


?>